;; Generated package description from project.el  -*- no-byte-compile: t -*-
(define-package "project" "0.9.8" "Operations on the current project" '((emacs "26.1") (xref "1.4.0")) :commit "6c0d8210175e72dcd7cef2ad77b8f8b680b240bc" :url "https://elpa.gnu.org/packages/project.html")
